@@ -31,8 +31,8 @@ class server:
 
             if debug == True:
                 print ("Server is Listening.....")
-            HOST = 'egger-donau.de'
-            PORT = 9980
+            HOST = host
+            PORT = port
             s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             s.bind((HOST, PORT))
             s.listen(1)
